<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="XSLUtils fo Lang">
	<xsl:import href="pagingtemplate.xsl"/>
	<xsl:import href="templatedate.xsl"/>
	<xsl:import href="approvaltemplate.xsl" />
	<xsl:key name="projectStatusKey" match="/webcenter_page/project_status_list/custom_project_status" use="@id"/>
	<xsl:key name="DocTypeKey" match="/webcenter_page/doc_type_list/doc_type" use="@id"/>
	
	<!-- Those values should match TaskDB.Status values -->
    <xsl:variable name="task_started" select="'00001_0000000001'"/>
    <xsl:variable name="task_running" select="'00001_0000000002'"/>
    <xsl:variable name="task_finished_successfully" select="'00001_0000000003'"/>
    <xsl:variable name="task_finished_warnings" select="'00001_0000000004'"/>
    <xsl:variable name="task_failed" select="'00001_0000000005'"/>
    <xsl:variable name="task_data_flushed" select="'00001_0000000006'"/>
			
	<!-- Approval variables -->
   <xsl:variable name="approval_cycle_state">
	  <xsl:value-of select="/webcenter_page/doc_version/approval_cycle_state"/>
	</xsl:variable>
	<xsl:variable name="approval_state">
	  <xsl:value-of select="/webcenter_page/doc_version/approval_state"/>
	</xsl:variable>
	
	<xsl:variable name="stage_name">
	  <xsl:value-of select="/webcenter_page/doc_version/stage_name"/>
	</xsl:variable>
			
    <!--  check if this is a graphics file or digital film file -->
    <xsl:variable name="isOpenInViewer">
    	<xsl:choose>
    		<xsl:when test="XSLUtils:isViewableDoctype(/webcenter_page/doc_version/doctype_id, /webcenter_page/doc_version/document/name) = '1'" >
    			<xsl:value-of select="true()"/>
    		</xsl:when>
    		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
    	</xsl:choose>
    </xsl:variable>
	
	<!-- This variable keeps track of the source of the document. This will normally be a backstage source but it can come from any other system
		 The reason we want to keep track of this is that we do not want to show options that are not available for files coming from a different source and
		 the other way around.
	 -->
	<xsl:variable name="isSystemSource">    
		<xsl:choose>
    		<xsl:when test="/webcenter_page/doc_version/sourceid">
    			<xsl:value-of select="true()"/>
    		</xsl:when>
    		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
    	</xsl:choose>		
    </xsl:variable>

	<xsl:variable name="isPagelist">
		<xsl:choose>
	    		<xsl:when test="(/webcenter_page/doc_version/doctype_id ='00001_0000000014') ">
    				<xsl:value-of select="true()"/>
    			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	


	<xsl:variable name="isA3DFile">
		<xsl:choose>
	    		<xsl:when test="(/webcenter_page/doc_version/doctype_id ='00001_0000000003') ">
    				<xsl:value-of select="true()"/>
    			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
		
	<xsl:variable name="isDesingFile">
		<xsl:choose>
	    		<xsl:when test="(/webcenter_page/doc_version/doctype_id ='00001_0000000001') ">
    				<xsl:value-of select="true()"/>
    			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
		
	<xsl:variable name="isCanvasFile">
		<xsl:choose>
	    		<xsl:when test="(/webcenter_page/doc_version/doctype_id ='00001_0000000020') ">
    				<xsl:value-of select="true()"/>
    			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
		
	<xsl:variable name="isArtiosCADFile">
		<xsl:choose>
			<xsl:when test="$isDesingFile = 'true'">
				<xsl:value-of select="true()"/>
			</xsl:when>
    		<xsl:when test="(/webcenter_page/doc_version/doctype_id ='00001_0000000002')">
   				<xsl:value-of select="true()"/>
   			</xsl:when>
			<xsl:when test="$isCanvasFile = 'true'">
   				<xsl:value-of select="true()"/>
   			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
		
	<xsl:variable name="isCadXSupportedGraphics">
		<xsl:choose>
    		<xsl:when test="(/webcenter_page/doc_version/is_cadx_supported_graphics = '1')">
				<xsl:value-of select="true()"/>
   			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>	
	
	<xsl:variable name="has3DView">
		<xsl:choose>
			<xsl:when test="(/webcenter_page/doc_version/has3dview = '1')">
				<xsl:value-of select="true()" />
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="false()"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
		
	<!-- version revision number -->	
	<xsl:variable name="versionRevision" select="/webcenter_page/doc_version/revision"/>	
	<xsl:variable name="revisionLetter" select="/webcenter_page/doc_version/revision_letter"/>	
	<!-- default value of no revision; corresponds with DocVersion.NoRevision value -->
	<xsl:variable name="noRevision" select="number(0)"/>	
	
	<xsl:variable name="isURL" select="/webcenter_page/doc_version/document/is_url"/>
		
	<!-- variable that checks if view data is available by the doc task status -->
	<!-- bugfix 10972: what happens here? Well, the non-existence of a task record has another meaning for 
	     design files as it does for grahic files. For design files, when the files are uploaded in a very old version of webcenter,
	     then the task record is not there and the view files are not there. 
	     For graphic files, if they are uplaoded from BS and the view files are copied, then there is no taslk record at all because the task was never needed. 
	     (we cannot get away by putting a task finished record there becasue we have already the situation in the field where we do have view files but no task record :-( )
	     Anyway, so the logic is: when we are dealing with design files, we demand that the task record is there,
	     for graphic files, a non existing record means that the files are there by a copy operation. 
	 -->
	<xsl:variable name="isViewDataAvailable">
		<xsl:choose>
			<xsl:when test="(/webcenter_page/doc_version/doc_task/status_id = $task_finished_successfully) or
			    ( ($isArtiosCADFile = 'false') and count(/webcenter_page/doc_version/doc_task)=0 ) or
				(/webcenter_page/doc_version/doc_task/status_id = $task_finished_warnings)">
				<!-- view data is available -->				
				<xsl:value-of select="true()"/>
			</xsl:when>
			<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
		</xsl:choose>
	</xsl:variable>		
	
	<xsl:variable name="docTypeId" select="/webcenter_page/doc_version/doctype_id"/>
	<xsl:variable name="PDFProofing" select="/webcenter_page/doc_version/PDF_For_Proofing"/>
	
	<!-- Variable for all supported by viewer doctypes -->
    <xsl:variable name="isSupportedViewerDocType" select="XSLUtils:isViewableDoctype(/webcenter_page/doc_version/doctype_id, /webcenter_page/doc_version/document/name) = '1'" />

    <!-- Variable that identifies the current document as a CHILI document -->
    <xsl:variable name="isChiliDoc">
    	<xsl:choose>
    		<xsl:when test="$docTypeId='00001_0000000018'">
    			<xsl:value-of select="true()"/>
    		</xsl:when>
    		<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
    	</xsl:choose>
    </xsl:variable>
	
    <xsl:variable name="hasTaskManagementLicense" select="count(/webcenter_page/has_task_management_license) > 0"/>
    
    <xsl:variable name="hasAssetManagement" select="boolean(/webcenter_page/dam/externaldocid)" />
    	
  <!-- 
  
            template that controls the generation of the menus and doc header (thumbnail, description, ...)
            
  -->
  <xsl:template name="header">
	<!--
		Search Results paging uses a different form than the rest of the page for historical reasons.
		The next/previous links which use this form are located on a different form but that is not a problem.
		It is important thing is that this form not become nested inside of the page's main form.
	-->
	<form name="detailslinksform" method="post" action="docdetails.jsp"> 
		<input type="hidden" name="docSearchIndex" value=""/>
	</form>
	<form name="docactionform" method="post" action="dodocdetailsactions.jsp">
		<input type="hidden" name="actionVal" value=""/>
		<input type="hidden" name="pageURL" value=""/>
		<input type="hidden" name="GeneratingViewsOngoing" value="0"/>
		<!-- The source page input gets used after functions like add to cart to redirect you back here. -->
		<input type="hidden" name="sourcePage">
			<xsl:choose>
				<xsl:when test="doc_search_index &gt; 0">
					<xsl:attribute name="value">docdetails.jsp?searchDocVerID=<xsl:value-of select="doc_version/@id"/>&amp;docSearchIndex=<xsl:value-of select="doc_search_index"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="value">docdetails.jsp?docVerID=<xsl:value-of select="doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
		</input>
		<input type="hidden" name="docVerID" value="{doc_version/@id}"/>
		<input type="hidden" name="docTypeId" value="{$docTypeId}"/>
		
		<xsl:call-template name="menuFileHiddenInput"/>	  
		<xsl:call-template name="newDisplayDocDetailsHeader"/>
	</form>
	
  </xsl:template>
  
  <!-- 
		Template to show configurable document header actions  
   -->
	<xsl:template name="docDetailsConfigurableHeaderActions">
		<xsl:param name="actionMenuName"/>

		<!-- display lock/unlock/upload a new version based on the current status -->
		<xsl:variable name="documentOwnerID" select="/webcenter_page/doc_version/document/checkout_owner_id"/>
		<xsl:variable name="loginUserID" select="/webcenter_page/loginuserid"/>
		<xsl:variable name="isDonInSingleProject" select="count(/webcenter_page/project_list/project)"/>
		<xsl:variable name="isProjectActive">
			<xsl:choose>
				<xsl:when test="number($isDonInSingleProject) = 1">
					<xsl:value-of select="key('projectStatusKey',/webcenter_page/project_list/project/status_id)/is_active"/>
				</xsl:when>
				<xsl:otherwise>1</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- 'inactiveProjMemberLimitedAccess' var is used to indicate a regular member is accessing a document in an inactive Project -->
		<!-- in these cases the regular project member can have no more then VIEW and DOWNLOAD permissions -->
		<xsl:variable name="inactiveProjMemberLimitedAccess">
			<xsl:choose>
				<xsl:when test="not($isProjectActive = '1') and not( (/webcenter_page/is_admin) or (/webcenter_page/is_project_manager_current_project) )">
					<xsl:value-of select="'1'"/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="'0'"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="isLocked" >
			<xsl:choose>
				<xsl:when test="string-length($documentOwnerID)>0">1</xsl:when>
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="displayUnlock">
			<xsl:choose>
				<!-- case of doc version owner -->
				<xsl:when test="($isLocked=1) and ($documentOwnerID = $loginUserID)">1</xsl:when>
				<!-- case of admin -->
				<xsl:when test="($isLocked=1) and (/webcenter_page/is_admin)">1</xsl:when>
				<!-- Anybody else can't unlock it -->
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- DT114301: anybody with download permissions can download a locked document -->
		<xsl:variable name="canDownloadWithLock">1</xsl:variable>
		<xsl:variable name="displayDirectUploadNewVersion" >
			<xsl:choose>
				<!-- case of doc version owner for active projects only! -->
				<xsl:when test="(	($isLocked=0)	or ($isSystemSource=true())	or ( ($isLocked=1) and ($documentOwnerID = $loginUserID) )	)	and ($isProjectActive = '1')">1</xsl:when>
				<!-- Anybody else can't upload a new version -->
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="displayDirectUploadNewVersionAdmin" >
			<xsl:choose>
				<xsl:when test="($isLocked=1) and (/webcenter_page/is_admin)">1</xsl:when>
				<!-- Anybody else can't unlock it -->
				<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- get Doc type ID -->
		<!--<xsl:variable name="isURL" select="doc_version/document/is_url"/> -->
		<!-- get permissions -->
		<xsl:variable name="view" select="/webcenter_page/doc_version/permission/view"/>
		<xsl:variable name="add" select="/webcenter_page/doc_version/permission/add"/>
		<xsl:variable name="update" select="/webcenter_page/doc_version/permission/update"/>
		<xsl:variable name="delete" select="/webcenter_page/doc_version/permission/delete"/>
		<xsl:variable name="checkout" select="/webcenter_page/doc_version/permission/checkout"/>
		<xsl:variable name="download" select="/webcenter_page/doc_version/permission/download"/>
		<xsl:variable name="changetask" select="/webcenter_page/doc_version/permission/change_task"/>		
		<!--  Check if this is a pdf file -->
		<xsl:variable name="docNameLength" select="string-length(/webcenter_page/doc_version/document/name)"/>
		<xsl:variable name="docNameExtension" select="substring(/webcenter_page/doc_version/document/name, $docNameLength -2, 3)"/>
		<xsl:variable name="isPDF">
			<xsl:choose>
				<xsl:when test="($docNameExtension = 'pdf') or($docNameExtension = 'PDF')"><xsl:value-of select="true()"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
			</xsl:choose>
 				</xsl:variable>
		<!--  Check if the document has a graphic extension (in that case it makes sense to generate the view files)-->
		<xsl:variable name="isGraphicDoc">
			<xsl:choose>
				<xsl:when test="has_graphic_extension"><xsl:value-of select="true()"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- Check whether we are dealing with a Graphic (PDF) file, that got uploaded as an 'other' document type -->
		<xsl:variable name="isGraphicAsOther">
			<xsl:choose>
				<xsl:when test="(/webcenter_page/doc_version/doctype_id = '00001_0000000005') and (count(has_graphic_extension) = 1)">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<!-- check whether teh view files are flushed  -->
		<xsl:variable name="viewFilesFlushed">
			<xsl:choose>
				<xsl:when test="(/webcenter_page/doc_version/doc_task/status_id = '00001_0000000006')">
					<xsl:value-of select="true()"/>
				</xsl:when>
				<xsl:otherwise><xsl:value-of select="false()"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<!-- Check for the effective value of 'Open In ArtiosCAD' mode type for the current Document -->
		<xsl:variable name="ArtiosCADOpenType" select="XSLUtils:getACADOpenModeVal(/webcenter_page/doc_version/doctype_id, $download, /webcenter_page/acad_doc_open_type)"/>
			
		<xsl:for-each select="key('menuItemKey', $actionMenuName)/menuitem">
		
			<!-- mailto action -->
			<xsl:call-template name="builtinaction">
				<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_MAILLINK'"/>
				<xsl:with-param name="href" select="'javascript:PerformDocumentAction(2)'"/>
			</xsl:call-template>
			
			<!-- Open/View Doc -->
			<xsl:if test="number($view) = 1">
				<!--  display view/open action for non-graphics and digital films -->
				<xsl:if test="(($isOpenInViewer = 'false') or ($isArtiosCADFile = 'true') or ($isA3DFile = 'true')) and ($isPDF = 'false') and ($isURL = 0)">
					<!-- choose which 'open' action type will be displayed -->
					<xsl:choose>
						<xsl:when test="not($ArtiosCADOpenType = 'None')">
							<!-- Open In Artios CAD -->
							<!-- only avaliable when:
								* the current Doc is an ArtiosCAD document
								* the User has Download permission on the Document
								* the User has either 'Standard' or 'Enterprise' ACAD Open Type enabled 
							 -->
							<xsl:variable name="openInACADJSString">javascript:OpenInACAD('<xsl:value-of select="$ArtiosCADOpenType"/>');</xsl:variable>							
							<xsl:call-template name="builtinaction">
								<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_OPENACAD'"/>
								<xsl:with-param name="href" select="$openInACADJSString"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<!-- Open -->
							<xsl:call-template name="builtinaction">
								<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_OPEN'"/>
								<xsl:with-param name="href" select="'javascript:PerformDocumentAction(1)'"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
				
				<!-- Display Open in Acrobat action for pdf files only -->
				<xsl:if test="($isPDF = 'true') and not($PDFProofing = 2) and ($isURL = 0)">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_OPENACROBAT'"/>
						<xsl:with-param name="href" select="'javascript:OpenPDF()'"/>
					</xsl:call-template>
				</xsl:if>
				<!-- when the file is a graphic file, show the "generate view files" action  -->		
				<!-- Only show when user has update permission  -->
				<xsl:if test="($isGraphicAsOther = 'true') or ($viewFilesFlushed = 'true')">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_REGENANDVIEW'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(15)'"/>
					</xsl:call-template>
				</xsl:if>
				<!-- View/Annotate is implemented for ARD/MFG/ACD/Graphics/Digital film doc types only -->
				<!-- Display that link if view data is available only but always display for ARD/MFG -->
				<xsl:if test="($isSupportedViewerDocType = 'true') and ($isURL = 0)">
					<xsl:if test="(($isViewDataAvailable = 'true') and ($isChiliDoc ='false')) 
						or (/webcenter_page/doc_version/doctype_id = '00001_0000000001')
						or (/webcenter_page/doc_version/doctype_id = '00001_0000000002')
						or (/webcenter_page/doc_version/doctype_id = '00001_0000000020')">
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_VIEWANDANNOTATE'"/>
							<xsl:with-param name="href" select="'javascript:PerformDocumentAction(13)'"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</xsl:if>
			
			<xsl:if test="/webcenter_page/doc_version/document/is_url = '0'">
				<!-- Variables to determine copy, upload new version and delete permission - these permissions are also used in the "move" action. Thus, this is to avoid duplicity(and future problems when one permission would be changed and the other not) -->
				<!-- the same approach is in projdetailsdocs.xsl  -->
				<xsl:variable name="allowedCopy" select="(number($download) = 1) and not($PDFProofing = 2) and ($canDownloadWithLock=1)"/>								
				<xsl:variable name="allowedDelete" select="((/webcenter_page/is_admin) or (number($delete)=1)) and not(/webcenter_page/no_doc_operations_inactive_proj) and ($isLocked=0)" />

				<!-- Add to Cart -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_ADDTOCART'"/>
					<xsl:with-param name="href" select="'javascript:PerformDocumentAction(3)'"/>
				</xsl:call-template>
							
				<!-- Upload a new version link -->
				<xsl:if test="( ( (/webcenter_page/is_admin) or (/webcenter_page/is_project_manager_current_project) ) or ( (number($checkout) = 1) and ($inactiveProjMemberLimitedAccess = '0') )) and  (not($isSystemSource  = 'true' and $isPagelist='true')) and ( ($isLocked=0) or ( ($isLocked=1) and ($documentOwnerID = $loginUserID) ) )">
					<!--  Display the sandard direct upload link -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_UPLOADVER'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(16)'"/>
					</xsl:call-template>
				</xsl:if>
				
				<!-- Generate Document Download (for PM/Admin or Member with Download permission) -->
				<xsl:if test="(/webcenter_page/doc_download_link_generation_allowed) and ((/webcenter_page/is_admin) or (/webcenter_page/is_project_manager_current_project) or (number($download) = 1))">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DOWNLOADLINK'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(21)'"/>
					</xsl:call-template>
				</xsl:if>
				
				<!-- Delete this version -->
				<!-- only users with delete permissions can delete the document version
					This is only possible when the document is not locked and when it is not a pl doucment-->
				<xsl:if test="number($delete)=1 and ($isLocked=0) and (/webcenter_page/doc_version/most_recent_doc_version = '1') 
					and (/webcenter_page/doc_version/version_number > 1) and not (/webcenter_page/doc_version/doctype_id = '00001_0000000014') and not(/webcenter_page/no_doc_operations_inactive_proj) and ($inactiveProjMemberLimitedAccess = '0')">
					<!--  display view action for non-graphics and digital films -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DELETEVER'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(18)'"/>
					</xsl:call-template>
 				</xsl:if>
						
				<!-- Lock document only if is not locked yet and is not a url -->
				<xsl:if test="(number($checkout) = 1) and ($inactiveProjMemberLimitedAccess = '0')">
				 	<xsl:if test="($isLocked=0) and (/webcenter_page/doc_version/document/is_url = '0')">
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_LOCK'"/>
							<xsl:with-param name="href" select="'javascript:PerformDocumentAction(6)'"/>
						</xsl:call-template>
						</xsl:if>
					</xsl:if>

				<!-- Unlock document only if it was previously locked -->
				<xsl:if test="(number($checkout) = 1) and ($displayUnlock = 1) and ($inactiveProjMemberLimitedAccess = '0')">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_UNLOCK'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(7)'"/>
					</xsl:call-template>
				</xsl:if>
				
				<!-- Move document: used permissions from download AND delete functionality -->
				<xsl:if test="$allowedCopy and $allowedDelete and ($inactiveProjMemberLimitedAccess = '0')">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_MOVE'"/>
						<xsl:with-param name="href" select="'javascript:MoveDocument()'"/>
					</xsl:call-template>
				</xsl:if>

				<!-- Copy document: only for users with download permissions -->
				<xsl:if test="$allowedCopy">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_COPY'"/>
						<xsl:with-param name="href" select="'javascript:CopyDocument()'"/>
					</xsl:call-template>
				</xsl:if>
				
				<!-- Delete document: only for users with delete permissions, not for linked documents -->
				<xsl:if test="$allowedDelete and ($inactiveProjMemberLimitedAccess = '0')">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DELETE'"/>
						<xsl:with-param name="href" select="'javascript:DeleteDocument()'"/>
					</xsl:call-template>
				</xsl:if>

				<!-- for designs allow to run it as a standard and view in 3D as another document action -->
				<xsl:if test="$isDesingFile = 'true'">
					<!-- check whether the design file has an attribute category (creation view) containing the attribute 'Board' -->
					<xsl:if test="count(/webcenter_page/allow_to_run_as_standard )>0 ">
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_RUNASSTD'"/>
							<xsl:with-param name="href" select="'javascript:CopyDocument(true)'"/>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="($isDesingFile = 'true') or ($isCanvasFile = 'true') or ($isA3DFile = 'true')">
					<!-- View in 3D VRML -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_VIEW3D'"/>
						<xsl:with-param name="href">
							<xsl:choose>
								<xsl:when test="($isDesingFile = 'true') or ($isCanvasFile = 'true')">
									<xsl:value-of select="'javascript:PerformDocumentAction(20)'"/>
								</xsl:when>
								<xsl:otherwise> <!--  when test="$isA3DFile = 'true'" -->
									<xsl:value-of select="'javascript:PerformDocumentAction(22)'"/>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:if test="($isDesingFile = 'true') or ($isCanvasFile = 'true') or ($isA3DFile = 'true') or (($isViewDataAvailable = 'true') and ($isCadXSupportedGraphics = 'true'))">
					<!-- View in 3D VRML -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_VIEW3DCOL'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(23)'"/>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:if test="$has3DView = 'true' and (number($update) = 1)">
					<!-- Delete 3D Perspective -->
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DEL3DCOL'"/>
						<xsl:with-param name="href" select="'javascript:PerformDocumentAction(24)'"/>
					</xsl:call-template>
				</xsl:if>	

				<xsl:if test="(number($download) = 1) and not($PDFProofing = 2) and ($canDownloadWithLock=1)">
					<xsl:choose>
						<xsl:when test="$isURL=1"> <!-- Do not download URL --></xsl:when>
						<xsl:when test="($isPDF = 1) and ($PDFProofing = 1)"> <!-- Show download PDF for printing only for pdf files -->
							<xsl:call-template name="builtinaction">
								<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DLPDFPRINT'"/>
								<xsl:with-param name="href" select="'javascript:PerformDocumentAction(4)'"/>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="builtinaction">
								<xsl:with-param name="name" select="'DOCUMENT_HEADER_ACTION_DOWNLOAD'"/>
								<xsl:with-param name="href" select="'javascript:PerformDocumentAction(4)'"/>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:if>
			</xsl:if>

			<!-- Show custom task actions only for versions linked into exactly one project -->
			<xsl:if test="count(/webcenter_page/project_list/project) = 1">
				<xsl:variable name="canChangeTask">
					<xsl:choose>
						<!-- no License -->
						<xsl:when test="not($hasTaskManagementLicense)">
							<xsl:value-of select="'0'"/>
						</xsl:when>
						<!-- admin and PM can always create tasks -->
						<xsl:when test="(/webcenter_page/is_admin) or (/webcenter_page/is_project_manager_current_project)">
							<xsl:value-of select="'1'"/>
						</xsl:when>
						<!-- when the project is not active, only PM and Admin can create tasks -->
						<xsl:when test="($isProjectActive = '0')">
							<xsl:value-of select="'0'"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$changetask"/>
						</xsl:otherwise> 
					</xsl:choose>
				</xsl:variable>

				<xsl:if test="$canChangeTask = '1'">
					<!-- Create Task -->
					<xsl:call-template name="createtaskaction">
						<xsl:with-param name="projectId" select="/webcenter_page/project_list/project/@id"/>
						<xsl:with-param name="docVersionId" select="/webcenter_page/doc_version/@id"/>
					</xsl:call-template>
						
					<!-- Start Workflow -->
					<xsl:call-template name="startworkflowaction">
						<xsl:with-param name="projectId" select="/webcenter_page/project_list/project/@id"/>
						<xsl:with-param name="docVersionId" select="/webcenter_page/doc_version/@id"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
				
			<!-- JavaScript -->
			<xsl:call-template name="javascriptaction">
				<xsl:with-param name="projectId" select="/webcenter_page/project_list/project/@id"/>
				<xsl:with-param name="docVersionId" select="/webcenter_page/doc_version/@id"/>
			</xsl:call-template>

		</xsl:for-each>
			
		<!-- additional items for the More actions dropdown from the menu system -->
		<xsl:variable name="menuitemname" select="'DOC_DETAILS_ACTIONS'"/>
		<xsl:variable name="menu" select="/webcenter_page/nav/menus/menuitem[name=$menuitemname]"/>
		<xsl:for-each select="$menu/menuitem">
			<xsl:variable name="scriptpart">
				<xsl:call-template name="substMenuSmartname">
					<xsl:with-param name="pattern" select="javascript"/>
				</xsl:call-template>
			</xsl:variable>
			<a class="action"
				href="javascript:{$scriptpart}"><xsl:call-template name="getMenuLabel"/></a>
		</xsl:for-each>										
	</xsl:template>   
  
  <!-- 
  	Template for new style document header
  -->
  <xsl:template name="newDisplayDocDetailsHeader">
  	<xsl:variable name="isCheckedOut" select="string-length(doc_version/document/checkout_owner_id)>0"/>
	<xsl:variable name="wizard">
		<xsl:call-template name="isWizardPage"/>
	</xsl:variable>
	<xsl:variable name="nameLink">
		<xsl:call-template name="isNameLink"/>		
	</xsl:variable>
	
	<div class="page-header details-header with-menu documentHeader">
			<h1>
				<!-- top bar actions -->
				<div class="action-menu-component header-action-buttons" data-init="component/actionmenu/HeaderActionMenu">
					<xsl:call-template name="docDetailsConfigurableHeaderActions">
						<xsl:with-param name="actionMenuName" select="'DOCUMENT_HEADER_TOP_ACTIONS'"/>								
					</xsl:call-template>
				</div>

				<xsl:variable name="isInSearchResults" select="doc_search_index &gt; 0"/>
				<xsl:if test="$isInSearchResults and ($wizard = 'false')">
						<div class="pull-right">	
						<xsl:call-template name="DisplayDetailsPaging">
							<xsl:with-param name="searchIndex" select="doc_search_index"/>
							<xsl:with-param name="totItemCnt" select="doc_search_total_cnt"/>
							<xsl:with-param name="Name" select="Lang:getStr(&lk;,'DOCUMENTDETAILS_TAG')"/>
							<xsl:with-param name="Type" select="'doc'"/>
						</xsl:call-template>
						</div>
				</xsl:if>
				
				<a class="btn btn-no-border details-section-toggle" data-toggle="collapse" data-target=".page-header .details-section"><i class="icon icon-mobile icon-WCR_Info2"></i></a>
				<xsl:value-of select="Lang:getStr(&lk;,'DOCUMENT')"/>:&nbsp;
				
				
				<xsl:choose>
					<xsl:when test="$nameLink = 'true'">
						<a>
							<xsl:call-template name="docDetailsHref">
								<xsl:with-param name="docVerID" select="doc_version/@id"/>
							</xsl:call-template>
							<xsl:value-of select="doc_version/document/name"/>
						</a>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="doc_version/document/name"/>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- LOCKED -->
				<xsl:if test="$isCheckedOut">
					<a class="btn btn-no-border header-align-middle"  title="{Lang:getStr(&lk;,'DOC_CHECKED_OUT')}">
						<i class="icon icon-normal icon-WCR_Lock"></i>
					</a>			
				</xsl:if>
					
			</h1>
			<div class="details-section collapse">
				<div class="details-static">
					<div class="details-section-content">
						<xsl:if test="$wizard = 'false'">
							<!-- Buttons -->
							<div class="details-action-buttons action-menu-component vertical" data-max-items="4" data-init="component/actionmenu/VerticalActionMenu" data-init-priority="100">
								<xsl:call-template name="docDetailsConfigurableHeaderActions">
									<xsl:with-param name="actionMenuName" select="'DOCUMENT_HEADER_LEFT_ACTIONS'"/>								
								</xsl:call-template>
							</div>							
						</xsl:if>
						<div class="details-thumbnail">
							<a class="documentThumbnail">
								<xsl:if test="($isViewDataAvailable = 'true') 
									or (/webcenter_page/doc_version/doctype_id = '00001_0000000001')
									or (/webcenter_page/doc_version/doctype_id = '00001_0000000002')
									or (/webcenter_page/doc_version/doctype_id = '00001_0000000020')">
									<xsl:call-template name="docViewHref">
										<xsl:with-param name="sourcePage">docdetails.jsp%3FdocVerID=<xsl:value-of select="doc_version/@id"/>%26<xsl:call-template name="menuFileUrlParameter"/></xsl:with-param>
									</xsl:call-template>
								</xsl:if>
								<xsl:variable name="thumbnailUrl">
									<xsl:choose>
										<xsl:when test="version_thumbnail_url">
											<xsl:value-of select="version_thumbnail_url"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="doc_version/thumbnail_url"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:variable name="largeThumbnailUrl">
									<xsl:choose>
										<xsl:when test="version_large_thumbnail_url">
											<xsl:value-of select="version_large_thumbnail_url"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="concat('DownloadViewerThumbnail.jsp?docversionid=', doc_version/@id, '&amp;pix=500&amp;ajax=1')"/>
										</xsl:otherwise>
									</xsl:choose>
								</xsl:variable>
								<xsl:choose>
									<xsl:when test="not(starts-with(@thumbnailUrl, 'thumbnails')  )  ">
										<xsl:variable name="docNameEncoded">
											<xsl:value-of select="XSLUtils:encodeForJScript(doc_version/document/name)"/>
										</xsl:variable>
										<img border="0" onMouseout="delayhidethumb()" onMouseover="showthumb(event,'{$thumbnailUrl}','{$docNameEncoded}','202', null, '{$largeThumbnailUrl}', 500);" src="{$thumbnailUrl}"  align="top" width="100" height="100"/>
									</xsl:when>
									<xsl:otherwise>
										<img border="0" src="{$thumbnailUrl}"  align="top" width="100" height="100"/>
									</xsl:otherwise>
								</xsl:choose> 
				  			</a>
						</div>
					</div>
				</div>
				<div class="details-overflow">
					<div class="details-section-content">
						<div class="document-info">
							<xsl:variable name="hasPageList">
								<xsl:value-of select="(/webcenter_page/doc_version/doctype_id = '00001_0000000014') and (count(/webcenter_page/pagelistdocproperties/nr_pages) > 0)"/>
							</xsl:variable>
							<table class="document-info-table">
								<!--  Document Name -->
								<tr>
									<td class="td-label">
										<xsl:variable name="viewHref" select="key('DocTypeKey', $docTypeId)/view_jsp"/>
										<input type="hidden" name="viewHref" value="{$viewHref}"/>
										<xsl:value-of select="Lang:getStr(&lk;,'DOCUMENTDETAILS_TAG')"/>:&nbsp;
									</td>
									<td>
								  	<table cellspacing="0" cellpadding="0" border="0">
											<tr>
												<xsl:call-template name="DisplayDocName">
													<xsl:with-param name="nameLink" select="$nameLink"/>								
												</xsl:call-template>
												
												<!--  See if doc is checked out -->
												<xsl:if test="$isCheckedOut">
													<td style="padding: 0px;">
														<i class="icon icon-normal icon-WCR_Actions-Lock12" title="{Lang:getStr(&lk;,'DOC_CHECKED_OUT')}"/>														
													</td>
												</xsl:if>
												
												<!--  Check if it's in the cart -->
												<xsl:if test="is_in_cart">
												  <td style="padding: 0px;">
														&nbsp;<xsl:choose>
															<xsl:when test="$nameLink = 'true'">
																<a href="cartmgr.jsp" title="{Lang:getStr(&lk;,'DOC_IN_CART')}">
																	<i class="icon icon-WCR_Actions-Cart12"></i>
																	
																</a>
															</xsl:when>
															<xsl:otherwise>
																<i class="icon icon-WCR_Actions-Cart12" title="{Lang:getStr(&lk;,'DOC_IN_CART')}"></i>
															</xsl:otherwise>
														</xsl:choose>
													</td>
												</xsl:if>
		
												<!-- Always display a status icon for supported by viewer doc types if view data is not available with a link into action history page -->
												<xsl:if test="($isSupportedViewerDocType = 'true') and ($isViewDataAvailable = 'false')">
												  <td style="padding: 0px;"><xsl:call-template name="DisplayGenerateViewStatusIcon">
															<xsl:with-param name="nameLink" select="$nameLink"/>	
															<xsl:with-param name="statusID" select="doc_version/doc_task/status_id"/>							
														</xsl:call-template>	
													</td>
												</xsl:if>
											</tr>
										</table>
									</td>
									<!--  Document attributes -->
									<td class="header-attributes-cell">
										<xsl:variable name="hasProjectsAndTemplates">
												<xsl:value-of select="(count(project_list/project) > 0) and (count(template_list/project_list/project) > 0)"/>
										</xsl:variable>
										<xsl:attribute name="rowspan"> <!-- rowspan is all lines but the approval line -->
											<xsl:choose>										
												<xsl:when test="($hasPageList = 'true') and ($hasProjectsAndTemplates = 'true')">6</xsl:when>
												<xsl:when test="($hasPageList = 'true') or ($hasProjectsAndTemplates = 'true')">5</xsl:when>
												<xsl:otherwise>4</xsl:otherwise>
											</xsl:choose>
										</xsl:attribute>
										<div id="documentHeaderAttributesId"  class="header-attributes" style="margin:0; vertical-align:top;"/>
									</td>
								</tr>
								<!--  Pagelist Info -->
								<xsl:if test="$hasPageList = 'true'">
									<tr>
										<td class="td-label">
											<xsl:value-of select="Lang:getStr(&lk;,'PAGELIST_UPLOAD_PAGES')"/>:&nbsp; 
										</td>
										<td>
											<xsl:value-of select="/webcenter_page/pagelistdocproperties/nr_pages"/>
										</td>
									</tr>
								</xsl:if>
								<!--  Version Info -->
								<tr>
									<td class="td-label">
										<xsl:value-of select="Lang:getStr(&lk;,'VERSION')"/>:&nbsp;
									</td>
									<td>									
										<a>
											<xsl:call-template name="docViewVersionHistory"/> 
											<xsl:value-of select="doc_version/version_number"/>
										</a>
										
										<xsl:if test="number($versionRevision) > $noRevision">
											<span>
											&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'REVISION')"/>&nbsp;<xsl:value-of select="$revisionLetter"/></span>
										</xsl:if>
										
										
										<xsl:choose>
											<xsl:when test="not( doc_version/most_recent_doc_version = '1' or (/webcenter_page/doc_version/doctype_id = '00001_0000000014'))">
												<span class="danger">
												&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'HEADER_WAR_NOT_MOST_RECENT_VER')"/>!
												
													<a class="btn"> 
														<xsl:attribute name="href">javascript:redirectToLatestDocVersion()</xsl:attribute>
														<i class="icon icon-WCR_Actions-CurrentVersion12" title="{Lang:getStr(&lk;,'RELOAD_DOCUMENT_LATEST_VERSION')}"></i>
													</a>
													<script>
														function redirectToLatestDocVersion() {
															var href = "//" + location.host + location.pathname + "?docID=<xsl:value-of select="/webcenter_page/doc_version/document_id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";
															window.location.href = href;
														}
													</script>
								 				</span>
											</xsl:when>
											<xsl:when test="has_subversion = '1' and (/webcenter_page/doc_version/doctype_id = '00001_0000000018')">
												<span class="danger">&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'CHILI_HEADER_WAR_HAS_DRAFT')"/>!</span>
											</xsl:when>
										</xsl:choose>
										
										
									</td>
								</tr>
								<!--  Description -->
								<tr>
									<td class="td-label">
										<xsl:value-of select="Lang:getStr(&lk;,'DESCRIPTION')"/>:&nbsp;
									</td>
									<td>
										<xsl:choose>
											<xsl:when test="count(/webcenter_page/is_printing) &gt; 0">
												<xsl:value-of select="doc_version/document/description"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="CutDescription">	
													<xsl:with-param name="Description" select="doc_version/document/description"/>
													<xsl:with-param name="Width" select="'120'"/>
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>		
									</td>
								</tr>
								<!--  List of Projects and Templates -->
								<xsl:if test="count(project_list/project) > 0">
									<tr>
										<td class="td-label">
											<xsl:choose>
												<xsl:when test="count(project_list/project)>1"><xsl:value-of select="Lang:getStr(&lk;,'PROJMGMNTPROJS_TAG')"/>:</xsl:when>						
												<xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;,'PROJECT')"/>:</xsl:otherwise>
											</xsl:choose>&nbsp;
										</td>
										<td>
											<table class="projectList" border="0" cellpadding="0" cellspacing="0" data-init="component/contentoverflow/OverflowContentContainer" data-height="75">
												<xsl:variable name="docID" select="doc_version/document/@id" />
												<xsl:for-each select="project_list/project">
													<xsl:variable name="projectID" select="@id"/>
													<xsl:call-template name="DisplayProjectLink">
														<xsl:with-param name="nameLink" select="$nameLink"/>
														<xsl:with-param name="bomOrder" select="/webcenter_page/project_doc_bom_list/project_doc_bom[doc_id=$docID][project_id=$projectID]/order" />
													</xsl:call-template>
												</xsl:for-each>
											</table>
										</td>
									</tr>
								</xsl:if>
								<!-- Display templates if exist -->
				  			<xsl:if test="count(template_list/project_list/project) > 0">
				  				<tr>
										<td class="td-label">
											<xsl:choose>
												<xsl:when test="count(template_list/project_list/project)>1"><xsl:value-of select="Lang:getStr(&lk;,'PROJMGMNTTMPLTS_TAG')"/>:</xsl:when>						
												<xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;,'TEMPLATE')"/>:</xsl:otherwise>
											</xsl:choose>&nbsp;
										</td>
										<td>
											<table>
												<xsl:variable name="docID" select="doc_version/document/@id" />
												<xsl:for-each select="template_list/project_list/project">
													<xsl:variable name="projectID" select="@id"/>
													<xsl:call-template name="DisplayProjectLink">
														<xsl:with-param name="nameLink" select="$nameLink"/>
														<xsl:with-param name="bomOrder" select="/webcenter_page/project_doc_bom_list/project_doc_bom[doc_id=$docID][project_id=$projectID]/order" />
													</xsl:call-template>
												</xsl:for-each>
											</table>
										</td>
									</tr>
				  			</xsl:if>
				  			<!-- Approval info and links -->
				  			<tr>
									<td class="td-label">
										 <xsl:value-of select="Lang:getStr(&lk;,'HEADER_APPROVAL')"/>:&nbsp;
									</td>
									<td colspan="2"> <!-- span under the document attributes -->
										<!-- Convert the approval state ID to the lang key -->
										<xsl:variable name="approval_langKey">
											<xsl:choose>
												<xsl:when test="string-length($approval_state)>0">
													<xsl:value-of select="/webcenter_page/approval_types/approval_type_list/approval_type[@id=$approval_state]/label_tag"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="'APPROVAL_PENDING'"/>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
										<!-- Build approval cycle string -->
										<xsl:variable name="approval_cycle_info">
											<xsl:choose>
												<xsl:when test="($approval_cycle_state = 'cycle_started') ">
													<!-- Case of started status -->
													<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_HEADER_CYCSTARTED')"/>
												</xsl:when>
												<xsl:when test="($approval_cycle_state = 'cycle_finished') ">
													<!-- case of finished status -->
													<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_HEADER_CYCFINISHED')"/>
												</xsl:when>
												<xsl:when test="($approval_cycle_state = 'cycle_stopped') ">
													<!-- case of stopped status -->
													<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_HEADER_CYCSTOPPED')"/>
												</xsl:when>
												<xsl:when test="($approval_cycle_state = 'cycle_waiting_for_workflow') ">
													<!-- case of stopped status -->
													<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_HEADER_CYCWAITINGWORKFLOW')"/>
												</xsl:when>
												<xsl:otherwise>
													<xsl:value-of select="' '"/>
												</xsl:otherwise>
											</xsl:choose>
										</xsl:variable>
									<table border="0" cellpadding="0" cellspacing="0"><tr>	
									<td class="Black_11" valign="middle" nowrap="nowrap">
										<xsl:if test="string-length($stage_name)>0" >
											<xsl:value-of select="'Stage '"/>
											<xsl:value-of select="$stage_name"/>
											<xsl:value-of select="' - '"/>
										</xsl:if>
										<!-- Display approval info -->
										<xsl:choose>
											<xsl:when test="$approval_cycle_state = 'no_approval_rule'">
												<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_NO_APP_REQ')"/>
											</xsl:when>
											<xsl:when test="($approval_cycle_state = 'cycle_finished') ">
												<xsl:value-of select="Lang:getStr(&lk;,$approval_langKey)"/>		  			  	
											</xsl:when>
											<xsl:when test="($approval_cycle_state = 'cycle_stopped') ">
												<xsl:value-of select="$approval_cycle_info"/>
											</xsl:when>
											<xsl:when test="($approval_cycle_state = 'cycle_waiting_for_workflow') ">
												<xsl:value-of select="$approval_cycle_info"/>
											</xsl:when>
											<xsl:otherwise>
												<xsl:value-of select="$approval_cycle_info"/>
												<xsl:value-of select="' - '"/>
												<xsl:value-of select="Lang:getStr(&lk;,$approval_langKey)"/>		
											</xsl:otherwise>		
										</xsl:choose>
									</td>
									<xsl:if test="($approval_cycle_state != 'no_approval_rule')">
										<td class="Black_11" valign="middle">
											<xsl:call-template name="approvalStatusNoFormatting">
											  	<xsl:with-param name="approvalStatusID" select="$approval_state"/>
										  		<xsl:with-param name="approvalCycle" select="$approval_cycle_state"/>
										   		<xsl:with-param name="docVerID" select="doc_version/@id"/> <!-- to have approval details popup -->
										   		<xsl:with-param name="docName" select="doc_version/document/name"/> <!-- to have approval details popup -->
										   		<xsl:with-param name="projectID" select="doc_version/project_id"/> <!-- to have approval details popup -->
											</xsl:call-template>
										</td>
									</xsl:if>
									<!-- Show an appropriate action for the latest version only -->
									<td class="small_text_name_header_link" valign="middle" nowrap="nowrap">
											<xsl:if test="($nameLink = 'true') and ($wizard != 'true') and ( doc_version/most_recent_doc_version = '1')">
												<!-- Display approval links for documents in regular projects only! -->
												<xsl:if test="not(/webcenter_page/is_template)">
													<!-- Approval variables -->
													<xsl:variable name="approval_cycle_state" select="/webcenter_page/doc_version/approval_cycle_state"/>
													<xsl:variable name="approval_state" select="/webcenter_page/doc_version/approval_state"/>
													<xsl:variable name="approval_langKey" select="/webcenter_page/approval_types/approval_type_list/approval_type[@id=$approval_state]/label_tag"/>
													<xsl:variable name="is_approval_owner" select="name(/webcenter_page/is_approval_owner)"/>
													<xsl:variable name="is_doc_approver" select="name(/webcenter_page/is_doc_approver)"/>
													<xsl:variable name="is_project_manager" select="name(/webcenter_page/is_project_manager_current_project )"/>
													<xsl:variable name="isProjectActive" select="key('projectStatusKey',/webcenter_page/project_list/project/status_id)/is_active"/>
													<xsl:variable name="projectId" select="/webcenter_page/project/@id"/>
													
													<xsl:choose>
					   									<xsl:when test="$isURL=1"><!-- No approval actions on URL --></xsl:when>
					   									<xsl:otherwise>
															<xsl:if test="string-length($approval_state) &gt; 0">
																<xsl:if test="($approval_cycle_state='cycle_stopped') and ($isProjectActive = '1')">						
																	<!-- Allow to start and clear a cycle for approval owners when at least one approver is specified -->
																	<xsl:if test="(string-length($is_approval_owner) &gt; 0) ">
																		<!-- Start the cycle -->
												   						&nbsp;<a href="javascript:PerformDocumentAction(11);">
													  						<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_STATUS_STARTCYCLE_ACTION')"/>
																		</a>																					
																	</xsl:if>
																</xsl:if>
																<xsl:if test="($approval_cycle_state = 'cycle_started') and ($isProjectActive = '1')">
																	<!-- Allow to stop cycle to approval owners -->
																	<xsl:if test="string-length($is_approval_owner) &gt; 0">
																		&nbsp;<a href="javascript:PerformDocumentAction(12);">
																			<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_STATUS_STOPCYCLE_ACTION')"/>
																		</a>
																		<xsl:if test="string-length($approval_state)=0">
																		/
																		</xsl:if>
																	</xsl:if>
																</xsl:if>
																<xsl:if test="( (string-length($is_doc_approver) &gt; 0) or  (string-length($is_project_manager) &gt; 0) )">
																	<!-- do not show this link if document has forced approval -->
																	<xsl:if test="($approval_state != '00001_0000000004') and ($approval_state != '00001_0000000005')">
																		&nbsp;<a>
																			<xsl:attribute name="href">docdetailsapprovers.jsp?docVerID=<xsl:value-of select="doc_version/@id"/>&amp;menu_file=<xsl:value-of select="menu_file"/></xsl:attribute>
																			<xsl:value-of select="Lang:getStr(&lk;,'DOCDETAILSAPPINFO_TAG')"/>
																		</a>
																	</xsl:if>
																</xsl:if>
															</xsl:if>
														</xsl:otherwise>
													</xsl:choose>
												</xsl:if>
											</xsl:if>
										</td>
										</tr></table>
									</td>
								</tr>
							</table>
						</div>
						
					</div>
				</div>
			</div>			
				
			<xsl:if test="/webcenter_page/nav/menu3">
				<ul class="ThirdLevelMenu" data-init="component/thirdlevelmenu/ThirdLevelMenu">
					<xsl:for-each select="/webcenter_page/nav/menu3">
						<xsl:if test="position() = 1"> <!-- we only want one level 3 menu: there can be one from both the page and the menu_file -->
						<xsl:variable name="menu" select="key('menuItemKey', @menuitemname)"/>
						<xsl:variable name="selection" select="@selected"/>
						
						<!-- Here are the actual menu items -->
						<xsl:call-template name="detailsMenuLevel3">
							<xsl:with-param name="menu" select="$menu"/>
							<xsl:with-param name="selection" select="$selection"/>
						</xsl:call-template>
						</xsl:if>
					</xsl:for-each>
				</ul>
				<xsl:if test="/webcenter_page/nav/menu4">
					<ul class="FourthLevelMenu">
						<xsl:for-each select="/webcenter_page/nav/menu4">
							<xsl:call-template name="detailsMenuLevel4"/>
						</xsl:for-each>
					</ul>
				</xsl:if>
			</xsl:if>
			
		</div>	
		
				
		
	
		
  </xsl:template>
 
	
	
	<xsl:template name="DisplayProjectLink">
		<xsl:param name="nameLink" />
		<xsl:param name="bomOrder" />
		
		<xsl:variable name="projectID" select="@id" />
		<xsl:variable name="isProjectActive" select="key('projectStatusKey',status_id)/is_active"/>
		<xsl:variable name="isTemplate" select="is_template"/>
			<tr>
				<td class="small_text_name_header_link" style="padding:0px;"> <!-- already padding on the inner table -->
					<xsl:choose>
						<xsl:when test="$nameLink = 'true'">
							<a  valign="middle" align="left">
							  <xsl:call-template name="projectHref">
								<xsl:with-param name="projectID" select="$projectID"/>
								<xsl:with-param name="docVerID" select="/webcenter_page/doc_version/@id"/>
							  </xsl:call-template>
							  <xsl:value-of select="name"/>
							</a>
						</xsl:when>
						<xsl:otherwise>
							  <xsl:value-of select="name"/>
						</xsl:otherwise>	
					</xsl:choose>					
					<xsl:if test="($isTemplate = '0') and ($isProjectActive = '0')">
					   &nbsp;
					   <span class="label label-danger">
					   		<xsl:value-of select="Lang:getStr(&lk;, key('projectStatusKey', status_id)/status_type)"/>						
				      </span>						
					</xsl:if>
					<xsl:if test="/webcenter_page/bom_enabled=1 and $bomOrder">
						<!-- <xsl:variable name="curPage" select="floor(($bomOrder - 1) div /webcenter_page/page_size) + 1" />  -->
						&nbsp;
						<a>
							<xsl:call-template name="docInBOMHref">
								<xsl:with-param name="projectID" select="$projectID"/>
							</xsl:call-template>
							<i class="icon icon-WCR_Actions-BOM12 icon-green"  title="{Lang:getStr(&lk;,'DOC_IN_BOM')}"/>
						</a>
					</xsl:if>
				</td>
			</tr>
		
	</xsl:template>
	
	<!-- Generate the href for the document in project BOM icon -->
	<xsl:template name="docInBOMHref">
		<xsl:param name="projectID" />
		<xsl:attribute name="href">
			<xsl:value-of select="concat('projdetailsbom.jsp?projectID=', $projectID , '&amp;menu_file=', /webcenter_page/menu_file/.)"/>
		</xsl:attribute>
	</xsl:template>
	
	<!-- This tempalte should be overwritten -->
	<xsl:template name="DocName"/>
 
 <!--	
	Template that displays a document name in the doc. details header.
	For non-graphic files it is a link to an appropriate open page.
	For graphic files if view data is available then open a viewer,
	otherwise display the name only without any link.
  -->
  <xsl:template name="DisplayDocName">
	  <xsl:param name="nameLink" />															  
							  
				<td class="darktext_darklink_11" nowrap="nowrap" style="padding: 0px;">
					<xsl:choose>
						<xsl:when test="$nameLink = 'true'">
							<!-- first check if this open should go to the viewer -->
							<a> 
								<xsl:call-template name="docViewHref">
									<xsl:with-param name="sourcePage">docdetails.jsp%3FdocVerID=<xsl:value-of select="doc_version/@id"/>%26<xsl:call-template name="menuFileUrlParameter"/></xsl:with-param>
								</xsl:call-template>
								<xsl:value-of select="doc_version/document/name"/>
							</a>
						</xsl:when>
						<xsl:otherwise>
							<!-- name only without a link -->
							<xsl:value-of select="doc_version/document/name"/>
						</xsl:otherwise>
					</xsl:choose>
				</td>

			 	<!-- doc file size  -->
		 		<xsl:if test="doc_version/file_size != 0">
					<td class="darktext_darklink_10" style="padding: 0px;">
				 		<small>
				 		<xsl:value-of select="'('"/>
					 	 <xsl:call-template name="FormatFileSize">
						 	 <xsl:with-param name="filesize" select="doc_version/file_size"/>
					 	 </xsl:call-template>
				 		<xsl:value-of select="')'"/></small>
					</td>
		 		</xsl:if>
 
			 	<!-- PDF document has PDF annotations   -->
		 		<xsl:if test="doc_version/PDF_For_Proofing = 3">
					<td>
			 			<a href="javascript:OpenPDF();" title="{Lang:getStr(&lk;,'DOC_WITH_PDFANNOTATION')}">
			 				<xsl:attribute name="class">btn btn-xs btn-no-border</xsl:attribute>
							<i class="icon icon-WCR_Actions-Annotation-PDF12 icon-orange"></i>		
						</a>
					</td>
		 		</xsl:if>
 
				<!-- Document with annotations   -->
				<xsl:if test="/webcenter_page/has_annotation = 1">
					<td>				 		
						<a title="{Lang:getStr(&lk;,'DOC_WITH_ANNOTATION')}">
							<xsl:attribute name="class">btn btn-xs btn-no-border</xsl:attribute>
							<xsl:call-template name="docViewHref">
								<xsl:with-param name="docVerID" select="doc_version/@id"/>
								<xsl:with-param name="openOnAnnotation" select="true()"/>
							</xsl:call-template>							
							<i class="icon icon-WCR_Actions-Annotation12 icon-orange"></i>
						</a>
					</td>
				</xsl:if>
				
				<xsl:if test="$hasAssetManagement = true()">
					<td>				 		
						<a>
							<xsl:attribute name="title">
								<xsl:value-of select="Lang:getStr(&lk;,'DOC_WITH_ASSET_MANAGEMENT')"/>
							</xsl:attribute>
							<xsl:attribute name="href">
								<xsl:text>docdetailsgeninfo.jsp?docVerID=</xsl:text><xsl:value-of select="doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>
							</xsl:attribute>
							<xsl:attribute name="class">btn btn-xs btn-no-border</xsl:attribute>
							<i class="icon icon-WCR_Actions-AssetMngmt12"></i>
						</a>
					</td>
				</xsl:if>
  </xsl:template>
  
  <!--
  Wizards or multi-page features should override this to hide the action bar and the details menu
  -->
  <xsl:template name="isWizardPage">
    <xsl:value-of select="false()"/>
  </xsl:template>
  
  <!-- pages that do not have to show any links on names in the header should overwrite this -->
  <xsl:template name="isNameLink">
    <xsl:value-of select="true()"/>
  </xsl:template>
  
  <xsl:template name="detailsHref">
    <xsl:call-template name="docDetailsHref">
      <xsl:with-param name="page" select="url"/>
      <xsl:with-param name="docVerID" select="/webcenter_page/doc_version/@id"/>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template name="docDetailsHiddenInputs">
    <xsl:call-template name="menuFileHiddenInput"/>
    <input name="docVerID" value="{/webcenter_page/doc_version/@id}" type="hidden"/>
  </xsl:template>
  
  <xsl:template name="filterHiddenInputs">
    <xsl:call-template name="docDetailsHiddenInputs"/>
  </xsl:template>
  
  <!-- 
  
            template that decides how to display a task status icon (link ot just an icon)
			based on the type of the page (R/O or R/W)
            
  --> 
  <xsl:template name="DisplayGenerateViewStatusIcon">
	<xsl:param name="nameLink" />	
	<xsl:param name="statusID" />
	<table>
		<tr>
			<!-- icon -->
			<td >
				<xsl:call-template name="DisplayTaskStatusIcon">
					<xsl:with-param name="statusID" select="$statusID"/>
				</xsl:call-template>	
			</td>
			<!-- message -->
			<td nowrap="nowrap">			
				<xsl:variable name="statusText">
				<xsl:choose>
				  <xsl:when test="$statusID=$task_started">
					<xsl:value-of select="Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')"/>&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'STARTED_TASK_STATUS')"/>
				  </xsl:when>
				   <xsl:when test="$statusID=$task_running">
					<xsl:value-of select="Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')"/>&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'RUNNING_TASK_STATUS')"/>
				  </xsl:when>
			
				   <xsl:when test="$statusID=$task_finished_successfully">
					<xsl:value-of select="Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')"/>&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'DONE_SUCCESS_TASK_STATUS')"/>
				  </xsl:when>
			
				   <xsl:when test="$statusID=$task_finished_warnings">
					<xsl:value-of select="Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')"/>&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'DONE_WARNING_TASK_STATUS')"/>
				  </xsl:when>
			
				   <xsl:when test="$statusID=$task_failed">
					<xsl:value-of select="Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')"/>&nbsp;
					<xsl:value-of select="Lang:getStr(&lk;,'DONE_ERROR_TASK_STATUS')"/>
				  </xsl:when>
			
				   <xsl:when test="$statusID=$task_data_flushed">
					<xsl:value-of select="Lang:getStr(&lk;,'DONE_FILES_DELETED')"/>
				  </xsl:when>
				  <xsl:otherwise>
						<xsl:value-of select="'&nbsp;'"/>
				  </xsl:otherwise>
					
				</xsl:choose>	
				</xsl:variable>
	
	
				<xsl:choose>
					<xsl:when test="$nameLink = 'true'">	
						<!-- Display as a link -->			
						<a>
						  <xsl:attribute name="href">javascript:OpenActionHistory();</xsl:attribute>		
						  <xsl:choose>
							<!-- for failed status use red text color -->
							<xsl:when test="$statusID=$task_failed">
								<xsl:attribute name="class"><xsl:value-of select="'red_small'"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class"><xsl:value-of select="'text_italic'"/></xsl:attribute>
							</xsl:otherwise>
						  </xsl:choose>
						  <xsl:value-of select="$statusText"/>
						</a>
						
					</xsl:when>
					<xsl:otherwise>
							<!-- Display as a text -->
							<xsl:choose>
							<xsl:when test="$statusID=$task_failed">
								<xsl:attribute name="class"><xsl:value-of select="'red_small'"/></xsl:attribute>
							</xsl:when>
							<xsl:otherwise>
								<xsl:attribute name="class"><xsl:value-of select="'text_italic'"/></xsl:attribute>
							</xsl:otherwise>
						  </xsl:choose>
						  <xsl:value-of select="$statusText"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</td>
		</tr>
	</table>
  
  </xsl:template>
  
	 <xsl:template name="DisplayPageListErrorFeedback">
		<!-- pagelist error feedback -->
		<xsl:if test="/webcenter_page/pagelist_errors/pagelist_error">
			<div class="alert alert-danger alert-dismissible">
				<button type="button" class="close" data-dismiss="alert" aria-label="Close"><i class="icon-small icon-WCR_Close12"></i></button>
				<p>
					<xsl:value-of select="Lang:getStr(&lk;,'APPROVAL_PAGELIST_ERROR_PAGES')"/>:<br/>
					<ul>
						<xsl:for-each select="/webcenter_page/pagelist_errors/pagelist_error">
							<li><xsl:value-of select="page" />:&nbsp;<xsl:value-of select="Lang:getStr(&lk;,errortag)"/></li>
						</xsl:for-each>
					</ul>
				</p>
			</div>
		</xsl:if>
	</xsl:template>
  
   <!-- 
  
            template that displays a task status icon based on the current status
            
  -->
  <xsl:template name="DisplayTaskStatusIcon">
    <xsl:param name="statusID"/>		
    <xsl:choose>
      <xsl:when test="$statusID=$task_started">
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'STARTED_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Running-sub12"></i></i>
      </xsl:when>
       <xsl:when test="$statusID=$task_running">
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'RUNNING_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Running-sub12"></i></i>
		</xsl:when>

       <xsl:when test="$statusID=$task_finished_successfully">
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'DONE_SUCCESS_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Success-sub12"></i></i>
      </xsl:when>

       <xsl:when test="$statusID=$task_finished_warnings">
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'DONE_WARNING_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Warning-sub12"></i></i>
		</xsl:when>

       <xsl:when test="$statusID=$task_failed">
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'DONE_ERROR_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Failed-sub12"></i></i>
      </xsl:when>

       <xsl:when test="$statusID=$task_data_flushed"> 
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'DONE_FILES_DELETED')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Warning-sub12"></i></i>
		</xsl:when>

      <xsl:otherwise>
			<i class="icon containerIcon icon-normal icon-WCR_ViewStatus-cont12" title="{Lang:getStr(&lk;,'REGISTERING_TASK_STATUS')}"><i class="icon subIcon icon-normal icon-WCR_ViewStatus-Waiting-sub12"></i></i>
      </xsl:otherwise>
    </xsl:choose>	
  </xsl:template>
    
  <xsl:template name="displaylengthvalue">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="//user_units = 'metric'">
        <xsl:value-of select="format-number($value, '#0.0#')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="format-number(number($value) div 25.4, '#0.0##')"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="displayareavalue">
    <xsl:param name="value"/>
    <xsl:choose>
      <xsl:when test="//user_units = 'metric'">
        <xsl:value-of select="format-number(number($value) div 100.0, '#0.0###')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="format-number(number($value) div 645.16, '#0.0##')"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <!-- 
  
            template which writes the javascript needed for the project details header

  -->
  <xsl:template name="DocDetailsJavaScript">
  	<xsl:call-template name="hoversciptwithcopyright"/>&#xA;
    <script src="javascript/detailswin.js"/>&#xA;
    <script src="javascript/popup.js"/>&#xA;
    <script src="javascript/extpopup.js"/>&#xA;
    <script src="javascript/date.js"/>&#xA;
    <script src="javascript/webcenter_ajax.js"/>&#xA;
    <script src="javascript/webcenter_xml.js"/>&#xA;
    <script src="javascript/webcenter_html.js"/>&#xA;
    <script src="javascript/SendDocDownloadLink.js"/>&#xA;
  	<script src="javascript/approvalInfoPopup.js" type="text/javascript"/>&#xA;	
    
   	<xsl:call-template name="i18n">
		<xsl:with-param name="langVar" select="'dlLinkLangStrings'"/>
		<xsl:with-param name="keys">
			MAILTOSUBJECTDOC|
    		MAILTOSUBJECTDOCDOWNLOAD|
    		MAILTOSUBJECTDOCSDOWNLOAD|
    		GENERATE_DLLINKFAILED|
    		GENERATE_DLLINKFAILED_INVALID_PARAMS|
    		GENERATE_DLLINKFAILED_NONE_DOCS_ALLOWED|
    		GENERATE_DLLINKFAILED_INVALID_NAMEMAP_PARAM|
    		DOCS_DENIED_FEEDBACK_MESSAGE_START|
    		DOCS_DENIED_FEEDBACK_MESSAGE_END|
    		OVERSIZE_DOC_DL_MESSAGE_POPUP_TITLE|
    		OVERSIZE_DOC_DL_MESSAGE_CONFRIM|
    		CLOSE|
    		OPEN_NEW_EMAIL_MESSAGE
    	</xsl:with-param>
	</xsl:call-template>
    
    <script type="text/javascript">
      <xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;

	function Approve_Enabled() 
	{ 
	   return true;
	}  
  
    function PerformDocumentAction(selElem)
    {
    	var sendDlLinkMgr = new downloadDocLinkMailGenerator(dlLinkLangStrings);
    	
 	  if (selElem== 1)
      {
        // View
        <xsl:variable name="docTypeId" select="/webcenter_page/doc_version/doctype_id"/>
        <xsl:variable name="docType" select="key('DocTypeKey', $docTypeId)"/>
        var url = "viewdocument.jsp?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>&amp;sourcePage=docdetails.jsp%3FdocVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>%26<xsl:call-template name="menuFileUrlParameter"/>";

        var newWindowFlag = <xsl:value-of select="$docType/open_new_view_window"/>;
        if (newWindowFlag == '1')
        {
          window.open(url);
        }
        else
        {
          window.location = url;          
        }
        return;
      }
      else if (selElem== 2)
      {
      	//Send Link To
      	// prepare the hostURL, document version ID and name values
       	var docVersionID = '<xsl:value-of select="/webcenter_page/doc_version/@id"/>';
      	var documentName = '<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/doc_version/document/name)"/>';
      	var hostURL = "<xsl:value-of select="/webcenter_page/hosturl"/>";
      	
      	//prepare a dummy list of Document Version IDs and a VersionID-Name map
        var docVersionIDs = [];
        var docVersionNameMap = [];

        //add to the lists
        docVersionIDs.push(docVersionID);
        docVersionNameMap.push({id: docVersionID, name: documentName});
      	
      	//execute the action
      	sendDlLinkMgr.generateDocumentBatchLinkToMail(docVersionNameMap, hostURL);	
      	return;
      }
      else if (selElem== 3)
      {
      	// add to cart
        document.docactionform.actionVal.value = "AddDocToCart";
      }
      else if (selElem== 4)
      {
        // download
        <xsl:if test="string(/webcenter_page/doc_version/document/checkout_owner_id)">
        <xsl:variable name="msg">
          <xsl:call-template name="encodejs">
            <xsl:with-param name="string" select="Lang:getStr(&lk;,'CHECKED_OUT_DOWNLOAD_WARNING')"/>
          </xsl:call-template>
        </xsl:variable>
          if (!confirm('<xsl:value-of select="$msg"/>'))
          {
                  return;
          }
        </xsl:if>
        document.docactionform.actionVal.value = "DownloadDoc";
      }
      else if (selElem== 5)
      {
        // checkin
        document.docactionform.actionVal.value = "CheckinDoc";
      }
      else if (selElem== 6)
      {
        // checkout
        document.docactionform.actionVal.value = "CheckoutDoc";
      }
      else if (selElem== 7)
      {
        // undo checkout
        document.docactionform.actionVal.value = "UndoCheckoutDoc";
      }
       // Open document for approval
      else if (selElem== 9)
      {
        document.docactionform.actionVal.value = "Approve";       
      }
	  // go to approval wizard
	  else if (selElem== 10)
      {
        document.docactionform.actionVal.value = "SetApprovalWizard";       
      }
	  // start Approval cycle
	  else if (selElem== 11)
      {
	    // Give a warning if approval due date is in the past - ADD NOW !!!
		var dueDate = "<xsl:value-of select="/webcenter_page/doc_version/approval_due_date"/>";
		if (dueDate.length &gt; 0)
		{
			// duedate is defined. Compare it with a current date
			var currentTime = new Date();
			var dueDateTime = new Date(dueDate);		
			
			// Convert all days into one format	YYYY-MM-DD HH:MM:SS.ns
			var format = "M/d/yy h:m a";
			var curDateFormat = formatDate(currentTime, format);
			var dueDateFormat = formatDate(dueDateTime, format);

			// compareDates(date1,dateformat1,date2,dateformat2) 
			//   Compare two date strings to see which is greater.
			//   Returns:
			//   1 if date1 is greater than date2
			//   0 if date2 is greater than date1 of if they are the same
			//  -1 if either of the dates is in an invalid format					
			if (compareDates(dueDateFormat,format,curDateFormat,format) == 0)
			{
				if (!confirm('<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CONFIRM__APPROVAL_WHILE_DOC_EXPIRED')"/></xsl:call-template>'))
				{
				  return;
				}
			}
		}
		
        document.docactionform.actionVal.value = "StartApprovalCycle";       
      }
	  // stop Approval cycle
	  else if (selElem== 12)
      {
        document.docactionform.actionVal.value = "StopApprovalCycle";       
      }
	  // View/Annotate
	  else if (selElem== 13)
      {
	    // Analyze first if view data is available for ArtiosCAD 2D doc 		
		var doctypeID = document.docactionform.docTypeId.value;
		if (doctypeID == '00001_0000000001' || 
			doctypeID =='00001_0000000002' ||
			doctypeID =='00001_0000000020')
		{
			var existViewData = "<xsl:value-of select="$isViewDataAvailable"/>";
			
			if (existViewData == 'false')
			{
				if (!confirm('<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CONFIRM_CREATE_VIEW_DATA')"/></xsl:call-template>'))
				{
				  return;
				}
				
			}
		}
		document.docactionform.actionVal.value = "ViewAnnotate";       
      }
	  // Clear Approval settings
	  else if (selElem== 14)
      {
	  	if (!confirm('<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CONFIRM__APPROVAL_CLEAR_SETTINGS')"/></xsl:call-template>'))
		{
		  return;
		}	  
        document.docactionform.actionVal.value = "ClearAllApprovals";       
      }
	  else if (selElem== 15)
      {
		var update_permission = "<xsl:value-of select="/webcenter_page/doc_version/permission/update"/>";
		        
		var generatingViewsongoing = document.docactionform.GeneratingViewsOngoing.value ; 
	
		var doctype ="<xsl:value-of select="/webcenter_page/doc_version/doctype_id"/>";
		 
        // ask for confirmation, this is only needed when converting a non-graphic document into a graphic document.
        if (update_permission == 0 &amp;&amp; doctype == '00001_0000000005' )
        {
              alert('<xsl:call-template name="encodejs">
	        <xsl:with-param name="string" select="Lang:getStr(&lk;,'PROCESSING_VIEW_DATA_NO_PERM')"/>
      		</xsl:call-template>');
			document.docactionform.actionVal.value = "Refresh"; ;

        } 
		else if ( generatingViewsongoing == 1)
		{

              alert('<xsl:call-template name="encodejs">
	        <xsl:with-param name="string" select="Lang:getStr(&lk;,'PROCESSING_VIEW_DATA_STARTED')"/>
      		</xsl:call-template>');
			document.docactionform.actionVal.value = "Refresh"; ;
              	
		}
		else 
		{
			if (!confirm('<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CONFIRM_CREATE_VIEW_DATA')"/></xsl:call-template>'))
			{
		  		return;
			}
			// hid the generate view files link	        
			document.docactionform.GeneratingViewsOngoing.value = 1 ;		
	    	    document.docactionform.actionVal.value = "GenerateViewFiles";       
    
		}
	    
      } 
      else if (selElem == 16)
      {
      	// direct doc. version checkin
        document.docactionform.actionVal.value = "DirectCheckinDoc";
      }
	  else if (selElem == 17)
      { 
      	// direct doc. version checkin - ADMIN VERSION
        document.docactionform.actionVal.value = "DirectCheckinDocAdmin";
      }
      else if (selElem == 18) // delete this document version 
      { 
	      	var appOngoing = '<xsl:value-of select="/webcenter_page/doc_version /approval_cycle_state"/>';
	      	
	      	var msg = '<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'DELETEDOCVERSION_CONF')"/></xsl:call-template>'+'?';
	      	
	      	if ( appOngoing == 'cycle_started' )
	      	{
		    	var msg_appStarted = '<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'DELETEDOCVERSION_CONF_APP')"/></xsl:call-template>';
		    	msg = msg_appStarted +'. ' + msg;
	      	} 
	      		 
      		if (!confirm(msg))
				return;
			
			document.docactionform.actionVal.value = "DeleteDocVersion";				
      }
      else if (selElem == 20) // 3D Model for Design files
      { 		
			OpenNewDetailsWindow('doctypedesign3dview.jsp');				
			return;
      }
      else if (selElem == 21) // Doc. Download Link generation
      { 		      
      		var docVersionID = '<xsl:value-of select="/webcenter_page/doc_version/@id"/>';
      		var documentName = '<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/doc_version/document/name)"/>';
      		
      		//prepare dummy list of DocVersioID and a VerID-Name Map
      		var docVersionIDs = [];
            var docVersionNameMap = [];
            docVersionIDs.push(docVersionID);
            docVersionNameMap.push({id: docVersionID, name: documentName});
      		
      		sendDlLinkMgr.generateDocumentBatchDLLinkMail(docVersionIDs, docVersionNameMap);		
      		return;
      }
      else if (selElem == 22) // 3D Model for A3D files
      { 		
			OpenNewDetailsWindow('doctypea3dview.jsp');				
			return;
      }
      else if (selElem == 23) // Collada View for Design, A3D, and Graphics files
      { 		
			OpenNewDetailsWindow('viewdocument.jsp?show3D=1');
			return;
      } else if (selElem == 24){
      		// Remove 3D Perspective
      		if (!confirm('<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'DOCDETAILSDELETE3DVIEW_CONFIRMATION')"/></xsl:call-template>')){
      			//cancel action
      			return;
      		}
          	document.docactionform.actionVal.value = "Delete3DPerspective";
      }
      
      
       // post the request&#xA;
       document.docactionform.submit();
    }
    
    function OpenNewDetailsWindow(pagename)
    {
    	var url = pagename;
    	if(url.indexOf("?") === -1) {
    		url += "?";
    	} else {
    		url += "&amp;";
    	}
    	url += "docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>&amp;sourcePage=docdetails.jsp%3FdocVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>%26<xsl:call-template name="menuFileUrlParameter"/>";
		window.open(url);
    }

    function CopyDocument(runAsStandard)
    {
     	var url = "addnewdocument.jsp?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";
     	if (runAsStandard) 
     		url += "&amp;runstandard=1";
     	
		window.location = url;
      	return;
    }
    
    function MoveDocument()
    {
     	var url = "addnewdocument.jsp?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";     		
     	url += "&amp;moveDocument=1";
     	
		window.location = url;
      	return;
    }
    
    
    function DeleteDocument()
    {
    	var confirmMsg = '<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;, 'CONFIRMDELDOCALL')"/></xsl:call-template>';
    	if(confirm(confirmMsg)){
	     	document.docactionform.actionVal.value = "DeleteDocumentFromDetails";
	     	var projectId = '';
	
	    	<xsl:choose>
	    		<xsl:when test="/webcenter_page/current_project_id" >
	    			projectId = '<xsl:value-of select="/webcenter_page/current_project_id"/>';
	    		</xsl:when>
	    		<xsl:otherwise>
	    			projectId = '<xsl:value-of select="/webcenter_page/project_list/project/@id"/>';
	    		</xsl:otherwise>
	    	</xsl:choose>

			if (projectId.length > 0) {
	     		document.docactionform.sourcePage.value = "projdetailsdocs.jsp?projectID=" + projectId + "&amp;menu_file=myallprojects";
			} else {
	     		document.docactionform.sourcePage.value = "";
	     	}	
	        document.docactionform.submit();
        }
    }

    
    function OpenPDF(selElem)
    {
      // View
      var url = "<xsl:value-of select="key('DocTypeKey', /webcenter_page/doc_version/doctype_id)/view_jsp"/>?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";
       
      window.open(url);
      return;
    }
    
    //accepted 'openMode' param values are: "Standard"; "Enterprise"
    function OpenInACAD(openMode) {
    	if (openMode === null || openMode === "Standard") {
			//Open in a native app (ACAD file types need to be properly registered their MIME types) 
			//NOTE: Using 'Other' document type setting as we want to mimic the behavior
     	 	var url = '<xsl:value-of select="key('DocTypeKey', '00001_0000000005')/view_jsp"/>?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>';
      		window.location = url;
      		return;
    	} else if (openMode === "Enterprise") {
    		//use registered ACAD-Enterprise launcher protocol
    		var url = 'acade:@<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/project_list/project/name)"/>:<xsl:value-of select="XSLUtils:encodeForJScript(/webcenter_page/doc_version/document/name)"/>';
      		window.location = encodeURI(url);
      		return;   		
    	}
    }
	
    function OpenActionHistory()
    {
      var actionHistoryUrl = "docdetailsactionversionhistory.jsp?docVerID=<xsl:value-of select="/webcenter_page/doc_version/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";
		
      window.location = actionHistoryUrl;
      return;
    }    
			
		<xsl:if test="(/webcenter_page/doc_version/category_id) and (/webcenter_page/category/layout_empty = 0)">
			<xsl:if test="(count(/webcenter_page/project_list/project) > 0) or (count(/webcenter_page/template_list/project_list/project) > 0)">
		
			require(["attributecategory/AttributeCategory", "utils/ObjectArrayCloneUtil"], function(AttributeCategory, ObjectHandler){
				$(function() 
				{
					// show HEADER attributes
					var readURL = "GetAttributeCategoryXML.jsp?categoryid=" + '<xsl:value-of select="/webcenter_page/doc_version/category_id"/>';
					// ensure to only append the category's mod date when it is known
					<xsl:if test="/webcenter_page/category/mod_time_stamp">
						readURL  += '&amp;lastmodified='+ <xsl:value-of select="/webcenter_page/category/mod_time_stamp"/> ;
					</xsl:if>
					
					var projectID = '';
					var documentID = '<xsl:value-of select="/webcenter_page/doc_version/document/@id"/>' ;
					var docVersionID = '<xsl:value-of select="/webcenter_page/doc_version/@id"/>';
					var categoryID = '<xsl:value-of select="/webcenter_page/doc_version/category_id"/>';
					
					<xsl:choose>
						<xsl:when test="count(/webcenter_page/project_list/project) > 0">
							projectID = '<xsl:value-of select="/webcenter_page/project_list[1]/project/@id"/>';
						</xsl:when>
						<xsl:otherwise>
							projectID = '<xsl:value-of select="/webcenter_page/template_list/project_list[1]/project/@id"/>';
						</xsl:otherwise>
					</xsl:choose>
					
					var valuesURL = "GetAttributes.jsp?docverid="+docVersionID + "&amp;categoryid="+categoryID + "&amp;editable=0";
					
					var currentUser = ObjectHandler.getCloneOfObject(gCurrentUser);
					currentUser.canEditAttributes = false;
					var aCatOptions = new Object();
					aCatOptions.ACatObj = "documentHeaderAttributesId";
					aCatOptions.ACatPanel = "documentHeaderAttributesId";
					aCatOptions.readURL = readURL + "&amp;view=Header";
					aCatOptions.currentUser = currentUser;
					aCatOptions.valuesURL = valuesURL;
					aCatOptions.view = "Header";
					aCatOptions.prefix = "header_"; // not to interfere with attributes in document details
					aCatOptions.type = "document";
					aCatOptions.projectID = projectID;
					aCatOptions.documentID = documentID;
					aCatOptions.docVersionID = docVersionID;
					if (aCatOptions.docVersionID) {
						// to be used to detect cyclic dependencies in document references
						aCatOptions.docTableParentDocVerIDs = [docVersionID];
					}
					myACat = new AttributeCategory(aCatOptions);
					$("#documentHeaderAttributesId").show();
		
				});
			});
		</xsl:if>
	</xsl:if>
	
  <xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
  </script>&#xA;         
	<xsl:call-template name="DateJavaScript"/> 
  </xsl:template>
</xsl:stylesheet>
