<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="Lang">
  <xsl:import href="template.xsl"/>
  <xsl:import href="attributetemplates.xsl"/>
  <xsl:import href="templatedate.xsl"/>
  <xsl:import href="projdetails_template.xsl"/>

  
  <xsl:variable name="useTableBodyContainer" select="false()" />
 
  <!-- override templates to prevent them showing anything -->

  <xsl:template name="welcomeEtc" />

  <xsl:template name="headerUserActions"/>
  <xsl:template name="headerMenuBar"/>
  <xsl:template name="headerMenuScripts"/>
  
  <xsl:template name="isWizardPage">
    <xsl:value-of select="true()"/>
  </xsl:template>
  
  <xsl:template name="isNameLink">
    <xsl:value-of select="false()"/>
  </xsl:template>
    
  <xsl:template name="bodyextensions">
  	<xsl:attribute name="scroll">yes</xsl:attribute>
  </xsl:template>
  
  <xsl:template name="pagesubtitle">
		<!-- display secondary header -->
  		    <xsl:variable name="catDisplayName">
	        <xsl:choose>
	          <xsl:when test="/webcenter_page/category/name"><xsl:value-of select="/webcenter_page/category/name"/></xsl:when>
	          <xsl:otherwise>---</xsl:otherwise>
	        </xsl:choose>
	    </xsl:variable>
	   <xsl:variable name="catDisplayViewName">
	       <xsl:choose>
	         <xsl:when test="/webcenter_page/attrcatview"><xsl:value-of select="/webcenter_page/attrcatview"/></xsl:when>
	         <xsl:otherwise><xsl:value-of select="Lang:getStr(&lk;, 'ACLayoutDefault')"/></xsl:otherwise>
	       </xsl:choose>
	   </xsl:variable>
	
		<xsl:call-template name="DetailsAttributeHeader">
			<xsl:with-param name="catDisplayName" select="$catDisplayName"/>
			<xsl:with-param name="catDisplayViewName" select="$catDisplayViewName"/>
			<xsl:with-param name="isEditable" select="false()"/>
			<xsl:with-param name="changeActionValue" select="'SaveProjectAttributes'" />
			<xsl:with-param name="showPrintButton" select="true()" />
			<!-- when we are in a custom view, override the header with the label of the menu -->
			<xsl:with-param name="useLabelOfDetailsMenu" select="boolean(/webcenter_page/attrcatview)"/>
		</xsl:call-template>	
	</xsl:template>
   
  <!-- 
  
            template that controls the generation of the body content
            
  -->
  <xsl:template name="bodycontent">  
	
	<xsl:variable name="isPrinting">
		<xsl:call-template name="isPrinting"/>
	</xsl:variable>

    <xsl:choose>
    	<!-- No Category assigned : display the appropriate message -->
    	<xsl:when test="no_attr_category_msg">
    		<div class="alert alert-warning"><xsl:value-of select="Lang:getStr(&lk;,'PROJHASNOATTRSCATEGORY_TAG')"/></div>
    	</xsl:when>
    	<xsl:otherwise>
			
			<div id="ACatObj"></div>
			<div id="ACatPanel"></div>
	
    	</xsl:otherwise>
    </xsl:choose>
  </xsl:template>
    
 <!-- 
  
            template that controls the inclusion of javascript functionality 
            
  -->
  <xsl:template name="scriptincs">  
    <script src="javascript/TableSelection.js"/>&#xA;
    <script src="javascript/validate.js"/>&#xA;
    <script src="javascript/detailswin.js"/>&#xA;
	
    <script type="text/javascript">
      		
        function PrintWindow()
        {
			window.print();
        }
            
    </script>
    <style>
      #ui-datepicker-div
      {
      z-index: 9999999;
      }
    </style>
    <script type="text/javascript">
      <xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;
		<xsl:if test="/webcenter_page/category/@id">
		
		var readURL = "GetAttributeCategoryXML.jsp?categoryid=" + '<xsl:value-of select="/webcenter_page/category/@id"/>'; 
		// ensure to only append the category's mod date when it is known
		<xsl:if test="/webcenter_page/category/mod_time_stamp">
			readURL  += '&amp;lastmodified='+ <xsl:value-of select="/webcenter_page/category/mod_time_stamp"/> ;
		</xsl:if>
	
		var valuesURL = "GetAttributes.jsp?projectid=" +'<xsl:value-of select="/webcenter_page/project/@id"/>';
		require(["attributecategory/AttributeCategory", "utils/ObjectArrayCloneUtil"], function(AttributeCategory, ObjectHandler){
			$(function() {			
				var currentUser = ObjectHandler.getCloneOfObject(gCurrentUser);
				currentUser.canEditAttributes = false;
				var aCatOptions = new Object();
				aCatOptions.ACatObj = "ACatObj";
				aCatOptions.isTemplate = <xsl:value-of select="/webcenter_page/project/is_template"/>;
				aCatOptions.ACatPanel = "ACatPanel";
				aCatOptions.readURL = readURL;
				aCatOptions.currentUser = currentUser;
				aCatOptions.valuesURL = valuesURL;
				aCatOptions.defaultHourAsHalfHours = <xsl:value-of select="/webcenter_page/default_due_date_time"/>;
				<xsl:if test="count(/webcenter_page/attrcatview)>0">
					aCatOptions.view='<xsl:call-template name="encodejs"><xsl:with-param name="string" select="/webcenter_page/attrcatview"/></xsl:call-template>';
					aCatOptions.readURL += '&amp;view=<xsl:call-template name="encodejs"><xsl:with-param name="string" select="/webcenter_page/attrcatview"/></xsl:call-template>';
				</xsl:if>
				aCatOptions.printLayout = true;
				aCatOptions.type = "project";
				aCatOptions.projectID = '<xsl:value-of select="/webcenter_page/project/@id"/>';
				myACat = new AttributeCategory(aCatOptions);
			});
		});
		</xsl:if>
      <xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
    </script>

    <xsl:call-template name="ProjDetailsJavaScript"/>  
	<xsl:call-template name="AttributeTemplateJavaScript"/>
  </xsl:template>
</xsl:stylesheet>
